Class: Aireview::ContextBuilder::Context

Inherits:
Struct
  • Object
show all
Defined in:
lib/aireview/context_builder.rb

Overview

The context of one run: both stages get the same MR, Jira and diff, truncated once for the tightest of the stages. sections — the MR and Jira part without the diff, for Jev.

Instance Attribute Summary collapse

Instance Attribute Details

#coverage ⇒ Object

Returns the value of attribute coverage

Returns:

  • (Object) —

    the current value of coverage



27
28
29
# File 'lib/aireview/context_builder.rb', line 27

def coverage
  @coverage
end

#diff_text ⇒ Object

Returns the value of attribute diff_text

Returns:

  • (Object) —

    the current value of diff_text



27
28
29
# File 'lib/aireview/context_builder.rb', line 27

def diff_text
  @diff_text
end

#sections ⇒ Object

Returns the value of attribute sections

Returns:

  • (Object) —

    the current value of sections



27
28
29
# File 'lib/aireview/context_builder.rb', line 27

def sections
  @sections
end

#sizes ⇒ Object

Returns the value of attribute sizes

Returns:

  • (Object) —

    the current value of sizes



27
28
29
# File 'lib/aireview/context_builder.rb', line 27

def sizes
  @sizes
end

#user_prompt ⇒ Object

Returns the value of attribute user_prompt

Returns:

  • (Object) —

    the current value of user_prompt



27
28
29
# File 'lib/aireview/context_builder.rb', line 27

def user_prompt
  @user_prompt
end