Exception: Aireview::RepairImpossibleError

Inherits:
ParseError show all
Defined in:
lib/aireview/errors.rb

Overview

Repairing invalid JSON is impossible: the model that answered is out of attempts or quarantined with no budget to wait. For the pipeline it is the same as an invalid result — the stage restarts on another model.