Class: Aireview::ContextBuilder::Context
- Inherits:
-
Struct
- Object
- Struct
- Aireview::ContextBuilder::Context
- Defined in:
- lib/aireview/context_builder.rb
Overview
The context of one run: both stages get the same MR, Jira and diff, truncated once for the tightest of the stages. sections — the MR and Jira part without the diff, for Jev.
Instance Attribute Summary collapse
-
#coverage ⇒ Object
Returns the value of attribute coverage.
-
#diff_text ⇒ Object
Returns the value of attribute diff_text.
-
#sections ⇒ Object
Returns the value of attribute sections.
-
#sizes ⇒ Object
Returns the value of attribute sizes.
-
#user_prompt ⇒ Object
Returns the value of attribute user_prompt.
Instance Attribute Details
#coverage ⇒ Object
Returns the value of attribute coverage
27 28 29 |
# File 'lib/aireview/context_builder.rb', line 27 def coverage @coverage end |
#diff_text ⇒ Object
Returns the value of attribute diff_text
27 28 29 |
# File 'lib/aireview/context_builder.rb', line 27 def diff_text @diff_text end |
#sections ⇒ Object
Returns the value of attribute sections
27 28 29 |
# File 'lib/aireview/context_builder.rb', line 27 def sections @sections end |
#sizes ⇒ Object
Returns the value of attribute sizes
27 28 29 |
# File 'lib/aireview/context_builder.rb', line 27 def sizes @sizes end |
#user_prompt ⇒ Object
Returns the value of attribute user_prompt
27 28 29 |
# File 'lib/aireview/context_builder.rb', line 27 def user_prompt @user_prompt end |